[llvm] d5bc1f4 - [SandboxVec][NFC] Rename a variable

Vasileios Porpodas via llvm-commits llvm-commits at lists.llvm.org
Wed Sep 11 09:05:28 PDT 2024


Author: Vasileios Porpodas
Date: 2024-09-11T09:04:59-07:00
New Revision: d5bc1f4a16194a41585240568c2818d163c6055b

URL: https://github.com/llvm/llvm-project/commit/d5bc1f4a16194a41585240568c2818d163c6055b
DIFF: https://github.com/llvm/llvm-project/commit/d5bc1f4a16194a41585240568c2818d163c6055b.diff

LOG: [SandboxVec][NFC] Rename a variable

Added: 
    

Modified: 
    llvm/lib/Transforms/Vectorize/SandboxVectorizer/SandboxVectorizer.cpp

Removed: 
    


################################################################################
diff  --git a/llvm/lib/Transforms/Vectorize/SandboxVectorizer/SandboxVectorizer.cpp b/llvm/lib/Transforms/Vectorize/SandboxVectorizer/SandboxVectorizer.cpp
index e9be6f5283fea7..c5d2ebf5156843 100644
--- a/llvm/lib/Transforms/Vectorize/SandboxVectorizer/SandboxVectorizer.cpp
+++ b/llvm/lib/Transforms/Vectorize/SandboxVectorizer/SandboxVectorizer.cpp
@@ -28,24 +28,24 @@ PreservedAnalyses SandboxVectorizerPass::run(Function &F,
   return PA;
 }
 
-bool SandboxVectorizerPass::runImpl(Function &F) {
+bool SandboxVectorizerPass::runImpl(Function &LLVMF) {
   // If the target claims to have no vector registers early return.
   if (!TTI->getNumberOfRegisters(TTI->getRegisterClassForType(true))) {
     LLVM_DEBUG(dbgs() << "SBVec: Target has no vector registers, return.\n");
     return false;
   }
-  LLVM_DEBUG(dbgs() << "SBVec: Analyzing " << F.getName() << ".\n");
+  LLVM_DEBUG(dbgs() << "SBVec: Analyzing " << LLVMF.getName() << ".\n");
   // Early return if the attribute NoImplicitFloat is used.
-  if (F.hasFnAttribute(Attribute::NoImplicitFloat)) {
+  if (LLVMF.hasFnAttribute(Attribute::NoImplicitFloat)) {
     LLVM_DEBUG(dbgs() << "SBVec: NoImplicitFloat attribute, return.\n");
     return false;
   }
 
-  sandboxir::Context Ctx(F.getContext());
-  // Create SandboxIR for `F`.
-  sandboxir::Function &SBF = *Ctx.createFunction(&F);
+  sandboxir::Context Ctx(LLVMF.getContext());
+  // Create SandboxIR for `LLVMF`.
+  sandboxir::Function &F = *Ctx.createFunction(&LLVMF);
   // TODO: Initialize SBVec Pass Manager
-  (void)SBF;
+  (void)F;
 
   return false;
 }


        


More information about the llvm-commits mailing list